@@ -39,6 +39,7 @@ from robot.utils.escaping import split_from_equals, unescape
 from robot.variables.search import is_variable
 
 from robotcode.core.concurrent import check_current_task_canceled
+from robotcode.core.language import language_id
 from robotcode.core.lsp.types import (
     Position,
     Range,
@@ -49,6 +50,7 @@ from robotcode.core.lsp.types import (
     SemanticTokensPartialResult,
     SemanticTokenTypes,
 )
+from robotcode.core.text_document import TextDocument, range_to_utf16
 from robotcode.robot.diagnostics.library_doc import (
     ALL_RUN_KEYWORDS_MATCHERS,
     BUILTIN_LIBRARY_NAME,
@@ -57,6 +59,8 @@ from robotcode.robot.diagnostics.library_doc import (
     KeywordMatcher,
     LibraryDoc,
 )
+from robotcode.robot.diagnostics.model_helper import ModelHelper
+from robotcode.robot.diagnostics.namespace import DEFAULT_BDD_PREFIXES, Namespace
 from robotcode.robot.utils import get_robot_version
 from robotcode.robot.utils.ast import (
     iter_nodes,
@@ -64,19 +68,13 @@ from robotcode.robot.utils.ast import (
     token_in_range,
 )
 
-from ...common.decorators import language_id
-from ...common.text_document import TextDocument, range_to_utf16
-from ..diagnostics.model_helper import ModelHelper
-from ..diagnostics.namespace import DEFAULT_BDD_PREFIXES, Namespace
 from .protocol_part import RobotLanguageServerProtocolPart
 
 if get_robot_version() >= (5, 0):
     from robot.parsing.model.statements import ExceptHeader, WhileHeader
 
 if TYPE_CHECKING:
-    from robotcode.language_server.robotframework.protocol import (
-        RobotLanguageServerProtocol,
-    )
+    from ..protocol import RobotLanguageServerProtocol
 
 
 ROBOT_KEYWORD_INNER = "KEYWORD_INNER"
@@ -111,6 +109,7 @@ class RobotSemTokenTypes(Enum):
     FOR_SEPARATOR = "forSeparator"
     VARIABLE_BEGIN = "variableBegin"
     VARIABLE_END = "variableEnd"
+    VARIABLE_EXPRESSION = "variableExpression"
     ESCAPE = "escape"
     NAMESPACE = "namespace"
     ERROR = "error"
@@ -159,7 +158,10 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart):
         # parent.semantic_tokens.collect_range.add(self.collect_range)
         # parent.semantic_tokens.collect_full_delta.add(self.collect_full_delta)
 
-        parent.documents_cache.namespace_invalidated.add(self.namespace_invalidated)
+        self.parent.on_initialized.add(self._on_initialized)
+
+    def _on_initialized(self, sender: Any) -> None:
+        self.parent.documents_cache.namespace_invalidated.add(self.namespace_invalidated)
 
     @language_id("robotframework")
     def namespace_invalidated(self, sender: Any, namespace: Namespace) -> None:
@@ -321,13 +323,13 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart):
             cls._mapping = cls.generate_mapping()
         return cls._mapping
 
-    ESCAPE_REGEX: ClassVar["re.Pattern[str]"] = re.compile(
+    ESCAPE_REGEX: ClassVar = re.compile(
         r"(?P<t>[^\\]+)|(?P<x>\\(?:[\\nrt]|x[0-9A-Fa-f]{2}|u[0-9a-fA-F]{4}|U[0-9a-fA-F]{8}))|(?P<e>\\(?:[^\\nrt\\xuU]|[\\xuU][^0-9a-fA-F]))",
         re.MULTILINE | re.DOTALL,
     )
-    BDD_TOKEN_REGEX: ClassVar["re.Pattern[str]"] = re.compile(r"^(Given|When|Then|And|But)\s", flags=re.IGNORECASE)
+    BDD_TOKEN_REGEX: ClassVar = re.compile(r"^(Given|When|Then|And|But)\s", flags=re.IGNORECASE)
 
-    BUILTIN_MATCHER: ClassVar[KeywordMatcher] = KeywordMatcher("BuiltIn", is_namespace=True)
+    BUILTIN_MATCHER: ClassVar = KeywordMatcher("BuiltIn", is_namespace=True)
 
     @classmethod
     def generate_sem_sub_tokens(
@@ -354,27 +356,30 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart):
                         length = token.end_col_offset - token.col_offset
 
                     last_index = token.value.rfind("}")
+
+                    is_expr = token.value[1:2] == "{" and token.value[last_index - 1 : last_index] == "}"
+
                     if last_index >= 0:
                         yield SemTokenInfo(
                             token.lineno,
                             col_offset,
-                            2,
+                            3 if is_expr else 2,
                             RobotSemTokenTypes.VARIABLE_BEGIN,
                             sem_mod,
                         )
 
-                        yield SemTokenInfo.from_token(
-                            token,
-                            sem_type,
-                            sem_mod,
-                            col_offset + 2,
-                            last_index - 2,
-                        )
+                        # yield SemTokenInfo.from_token(
+                        #     token,
+                        #     RobotSemTokenTypes.VARIABLE_EXPRESSION if is_expr else sem_type,
+                        #     sem_mod,
+                        #     col_offset + (3 if is_expr else 2),
+                        #     last_index - (4 if is_expr else 2),
+                        # )
 
                         yield SemTokenInfo(
                             token.lineno,
-                            col_offset + last_index,
-                            1,
+                            col_offset + ((last_index - 1) if is_expr else last_index),
+                            2 if is_expr else 1,
                             RobotSemTokenTypes.VARIABLE_END,
                             sem_mod,
                         )
@@ -637,9 +642,11 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart):
                             token.lineno,
                             token.col_offset,
                         ),
-                        RobotSemTokenTypes.NAMED_ARGUMENT
-                        if isinstance(node, Variable)
-                        else SemanticTokenTypes.PARAMETER,
+                        (
+                            RobotSemTokenTypes.NAMED_ARGUMENT
+                            if isinstance(node, Variable)
+                            else SemanticTokenTypes.PARAMETER
+                        ),
                     )
                     yield SemTokenInfo.from_token(
                         Token(
@@ -1081,9 +1088,11 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart):
                     if isinstance(node, (KeywordCall, Fixture)):
                         kw_token = cast(
                             Token,
-                            node.get_token(Token.KEYWORD)
-                            if isinstance(node, KeywordCall)
-                            else node.get_token(Token.NAME),
+                            (
+                                node.get_token(Token.KEYWORD)
+                                if isinstance(node, KeywordCall)
+                                else node.get_token(Token.NAME)
+                            ),
                         )
 
                         for node_token in node.tokens:
@@ -1221,5 +1230,10 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart):
         document: TextDocument,
         previous_result_id: str,
         **kwargs: Any,
-    ) -> Union[SemanticTokens, SemanticTokensDelta, SemanticTokensDeltaPartialResult, None,]:
+    ) -> Union[
+        SemanticTokens,
+        SemanticTokensDelta,
+        SemanticTokensDeltaPartialResult,
+        None,
+    ]:
         return None
